package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````(!8``#0````PE````````#0`(``(
M`"@`'0`<``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!<````7````!`````$````!````````````````````N(T`
M`+B-```%`````!````$```#<C@``W)X``-R>``!8`@``J`8```8`````$```
M`@```/".``#PG@``\)X``.````#@````!@````0````$````3`$``$P!``!,
M`0``+````"P````$````!````%#E=&3,A@``S(8``,R&```<`0``'`$```0`
M```$````4N5T9-R.``#<G@``W)X``"0!```D`0``!`````$````O=7-R+VQI
M8F5X96,O;&0N96QF7W-O```'````!`````$```!.971"4T0```#*FCL$````
M!`````,```!085@``````&$```!D```````````````K````"P``````````
M````,@````P````[`````````"H``````````0```$8```!<`````````!H`
M``!%````!````!D````0````%@```#T```!2````6`````````!1````-P``
M`%,``````````````&````!B````*````%``````````/@```%\```!7````
M/P````````!"````'````"\```!6````(````"4`````````!0```$@`````
M````"0```"<```!C````50```$0````S````20```&$`````````6@``````
M```4````*0```$<````````````````````.````+0`````````'````6P``
M`$H````````````````````>````-`````````!+`````P```$``````````
M-@````````````````````````!#`````````#4```!-````70````````!>
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````/````````````````````````````````````
M```````````=````&P`````````D```````````````B````(P``````````
M````"@````@````8````%P```!4````````````````````-`````````"X`
M```L````,0`````````````````````````````````````````\````'P``
M`````````````````!(``````````````#H````"````)@````8`````````
M`````#D``````````````!,`````````3P```"$`````````.```````````
M````3`````````!!``````````````!.````$0```%0````P````60``````
M````````````````````````G0``````````````$@````P`````````````
M`!(````4```````````````2````C`,``(P@```#````$@`,`!P`````````
M`````"(````K```````````````2````,0``````````````$@```#@`````
M`````````!(````^```````````````2````G0,``%XH```K````$@`,`$4`
M`````````````!(```!B`P`````````````2````N`,```DT``!M````$@`,
M`(@``````````````!(```!-```````````````2````Q`,``#2A````````
M$``7`%T``````````````!(```!L```````````````2````<@``````````
M````$@```'D``````````````!(```"#```````````````2````C0```&!(
M````````$``-`),``````````````!(```"<```````````````2````\P(`
M````````````$@```*(``````````````!(```"P```````````````1````
MR`(`````````````(@```+T``````````````!(```#+`P``I2(``"0````2
M``P`V`,``,DB``#E````$@`,`.0#``!Q*0``0`@``!(`#``E`P``````````
M```2````RP``````````````%@```-X``````````````!(```!T`P``````
M```````2````Z0``````````````$@```/(```"`I0``!````!$`&`#Z````
M```````````2`````P$`````````````$@```%@#`````````````!(````/
M`0`````````````2````\0,```]"```1`@``$@`,`"(!`````````````!$`
M```T`0`````````````2````1`$`````````````$@```%(!````````````
M`!(```!7`0`````````````2````_`,``#"A```$````$0`7`&8!````````
M`````!(```!R`0`````````````2````@@$`````````````$@```)<!````
M`````````!(```"B`0`````````````2````AP,``(2E````````$``8``L#
M`````````````!(```"U`0`````````````2````-P0``"`6````````$@`,
M`,,!`````````````!(```#+`0`````````````2````UP$`````````````
M$@````8$``"N(P``1P0``!(`#`#=`0`````````````2````Z`$`````````
M````$@```!,$```@1```T0$``!(`#`#Y`0`````````````2````'00``#2A
M````````$``8`"D$``#3'P``4````!(`#``Q!```$$8``#<"```2``P```(`
M````````````$@```+`"`````````````"(````V!```(!8````````2``P`
M!P(`````````````$@````X"`````````````!(````^!```CR```!8"```2
M``P`2P0``(DH``#H````$@`,`%T$``#U)P``:0```!(`#``E`@``````````
M```2````[`(`````````````$@```#8"`````````````"````!*`@``````
M```````2````80(`````````````$@```'`"`````````````!(```!Y`@``
M```````````2````?P(`````````````$@```$L#`````````````!(```"$
M`@`````````````2````/@,``$"A```$````$0`8`(P"`````````````!(`
M``!I`P`````````````2````DP(`````````````$@```&L$``"T00``6P``
M`!(`#`":`@`````````````1````,P,```"A```$````$0`7`&X$```0$@``
M`````!``"0!T!```L3$``%@"```2``P`&P$`````````````$@```)\"````
M`````````!(```![`P`````````````2`````&QI8G!E<FPN<V\`<F5A;&QO
M8P!M96UM;W9E`%]?8WAA7V9I;F%L:7IE`')M9&ER`'-T<G-T<@!C;&]S90!S
M=')C:'(`<W1R;F-M<`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`
M86)O<G0`=6YL:6YK`%]?;'-T870U,`!P97)L7V9R964`7V9I;FD`7U]S=&%T
M-3``7V5X:70`<&5R;%]D97-T<G5C=`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!?7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E=&-H<'8`7U]S<')I;G1F
M7V-H:P!R96%D`%!E<FQ?<WES7VEN:70S`%!E<FQ?9V5T7W-V`%]?7W1L<U]G
M971?861D<@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3`%!E<FQ?
M871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`4&5R;%]M9U]S
M970`;6MD:7(`<&5R;%]P87)S90!097)L7VYE=UA37V9L86=S`&%C8V5S<P!G
M971P:60`;65M8VAR`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``4&5R;%]A=&9O
M<FM?;&]C:P!?2G9?4F5G:7-T97)#;&%S<V5S`%]?<W1A8VM?8VAK7V9A:6Q?
M;&]C86P`4&5R;%]S=E]S971P=FX`<&5R;%]R=6X`;'-E96L`;W!E;@!S<')I
M;G1F`&=E='5I9`!S=')L96X`7U]S1@!S=')C;7``;&EB;2YS;RXP`%]?9&5R
M96=I<W1E<E]F<F%M95]I;F9O`%]?<F5G:7-T97)?9G)A;65?:6YF;P!L:6)C
M<GEP="YS;RXQ`'-T<F1U<`!F<')I;G1F`&QI8G!T:')E860N<V\N,0!P=&AR
M96%D7V%T9F]R:P!L:6)C+G-O+C$R`%]?<W1R;F-P>5]C:&L`7U]P<F]G;F%M
M90!?7W!S7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!A=&5X:70`
M7VQI8F-?:6YI=`!S=')T;VL`7U]R96%D9&ER,S``7V5N9`!P87)?8W5R<F5N
M=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%]E9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER
M`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`
M7U]B<W-?<W1A<G0`>'-?:6YI=`!M86EN`%]?<W1A<G0`<&%R7V9I;F1P<F]G
M`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?
M26YT97)N86QS7U!!4E]"3T]4`"]U<W(O<&MG+VQI8B]P97)L-2\U+C,V+C`O
M:3,X-BUN971B<V0M=&AR96%D+6UU;'1I+T-/4D4Z+W5S<B]P:V<O;&EB``#P
MGP``"`````"A```(````!*$```@````PH0``"````-"?```&!0``U)\```8/
M``#8GP``!AL``-R?```&'```X)\``"4B``#DGP``!BP``.B?```&-@``[)\`
M``9'``#TGP``!DX``/B?```&4```_)\```9=```,H```!P$``!"@```'`@``
M%*````<#```8H```!P8``!R@```'!P``(*````<(```DH```!PD``"B@```'
M"P``+*````<,```PH```!PX``#2@```'$0``.*````<2```\H```!Q,``$"@
M```'%```1*````<5``!(H```!Q<``$R@```'&```4*````<9``!4H```!QH`
M`%B@```''0``7*````<A``!@H```!R,``&2@```')```:*````<E``!LH```
M!R<``'"@```'*```=*````<I``!XH```!RH``'R@```'+0``@*````<N``"$
MH```!R\``(B@```',```C*````<R``"0H```!S,``)2@```'-```F*````<U
M``"<H```!S@``*"@```'.0``I*````<[``"HH```!SP``*R@```'/0``L*``
M``<_``"TH```!T```+B@```'0@``O*````=&``#`H```!TD``,2@```'2@``
MR*````=/``#,H```!U$``-"@```'4@``U*````=3``#8H```!U0``-R@```'
M50``X*````=6``#DH```!U<``.B@```'60``[*````=:``#PH```!UL``/2@
M```'80``^*````=B``#\H```!V,``````````````````%6)Y>AO!P``R<,`
M``````#_LP0```#_HP@`````````_Z,,````:`````#IX/____^C$````&@(
M````Z=#_____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C'```
M`&@@````Z:#_____HR````!H*````.F0_____Z,D````:#````#I@/____^C
M*````&@X````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I4/__
M__^C-````&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&````#I
M(/____^C0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````:'@`
M``#I\/[___^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4````
M:)````#IP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O___Z-@
M````:*@```#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP_O__
M_Z-L````:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT````.E`
M_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^____HX````!HZ```
M`.D0_O___Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP```!H
M``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____HY@`
M``!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]____
MHZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``Z6#]
M____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8`0``
MZ3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ````&AP
M`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^CT```
M`&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S___^C
MW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I@/S_
M__^CZ````&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!``#I
M4/S___^C]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z/\````:.`!
M``#I(/S___^CT/___V:0_Z/<____9I#_H^S___]FD/^C^/___V:04U+HDP$`
M`&:09I!FD&:0D%6)Y593Z`TR```%QHD``(V8W/[__XVPW/[__SGS<PG_$X/#
M!#GS<O=;7EW#58GE5U93@^P$Z.4Q``"!QY:)``")??"+4`P#4`2+`(U,D`B+
M`87`="R[__\``#'2ZQ*#^`,/A-8```"#P0B+`87`=":#^`5T%(/X!W7DBT$$
MA<!TYH/$!%M>7UW##[=9!(/!"(L!A<!UVH72=.=F@_O_=.'!XP6-#!HYRG/7
M,?^#SO_K$8/[!G4%B=8K<@B#PB`YT780BQJ#^P)UZ(G7@\(@.=%W\(7_=*N#
M_O]TIHM?"`'SBPN%R72;,=+K$8/Y$G4#BT,$@\,(BPN%R703@_D1=>J+4P0!
M\H/#"(L+A<EU[0'0.<)R$NEH____`3.#P@@YT`^&6____XL:`?,/MDH$@_D(
M=.:#^2ITX^F3+@``BU$$Z2+___]5B>575E.#[`3HQ#````5]B```B47PQ\,`
M````Q\8`````.?-S%X![!"H/A6,N``"+._\7B0>#PP@Y\W+I@\0$6UY?7<-5
MB>575E.#[!SH@S```('#.(@``(M]"(MU#(GPZ('^__^%]@^$]0```(V#0`$`
M`(DPC8.`!0``B<&)1>R+1@B)`8L&BQ"%T@^$O@```(V+``$``(D1BP`/MA"$
MTG01@\`!@/HO=?&)`0^V$(32=>^%_W0(B3PDZ'OZ___H=OW__XN#\/___X7`
M#X3*````C8/<_O__B47PC;O<_O__.<=S"O\7@\<$.WWP<O:-@S!V__^)!"3H
M/?K__XV#W/[__XE%\(V[W/[__SG'<PK_%X/'!#M]\'+VC8-@J/__B00DZ!+Z
M___H;?G__XM%[(L`B40D"(L&B40D!(M&!(D$).A3+0``B00DZ&OY__^-@P`!
M``"-DT0!``")$.E1____QT0D$!,```"-@VRH__^)1"0,QT0D"`(```#'!"0$
M````QT0D!`````#HROK__\<$)`$```#H'OK__^A>_O__Z2S___^+'"3#4U>#
M[`CH\O___X'#UH8``("[*0$```!U2,:#*0$```&#N]#___\`=`Z+@P0!``")
M!"3HJ?S__XV[Z/[__XL'A<!T!__0@\<(Z_.#N^S___\`=`Z-@V3I__^)!"3H
MC_S__X/$"%];PU-7@^P(Z(O___^!PV^&``"`NR@!````=5G&@R@!```!@[O<
M____`'08C;L(`0``B7PD!(V[9.G__XD\).A`_/__@[OX____`'04C;OL_O__
MBS^%_W0(B3PDZ#/\__^-N]S^__^+!X/X_W0'_]"#[P3K\H/$"%];PY!5B>57
M5E.#[!SH/2X``('#\H4``(E%[(E5Y(7`#X2A````B<*-@X`%``"+`(E%Z(7`
M#X2,````#[8"B=:$P`^$BP```#P]=`J#Q@$/M@:$P'7R*W7LB77PBW7HBSZ%
M_W0TB?B)]XG&BT7PB40D"(M-[(E,)`2)-"3H(_C__X7`=0F+1?"`/`8]=!6#
MQP2+-X7V==2)]XGX@\0<6UY?7<.)\(G^B<>)\2M-Z,'Y`HM%Y(D(BT7PC7P'
M`8GX@\0<6UY?7<,Q_XGX@\0<6UY?7</'1?``````ZX!5B>575E.![*0```#H
M8BT``('#%X4``(G&B[OD____BP>)1?`QP(7V=`6`/@!U%HM%\"L'#X50`0``
M@<2D````6UY?7<.)-"3HF_C__XF%</___X7`=-B-@X"H__^)A6C___^-A73_
M__^)A63___^+A7#___^)!"3HF_K__X7`#X3#````C5`-@'@-+G4&@'H!`'3;
M@'@-+@^$Q0```(F5;/___XDT).@\^O__B85@____BY5L____B10DZ"CZ__^+
MC6#___^-1`$"B00DZ";Z__^+E6S___^)5"0,B70D"(N-:/___XE,)`2)A6S_
M__^)!"3HP/G__XN-9/___XE,)`2+A6S___^)!"3H./?__X/X_W02BX5\____
M)0#P```]`$```'16BX5L____B00DZ./V__^+A6S___^)!"3HI?;__^DG____
MBX5P____B00DZ'+W__^)-"3H*O;__^G,_O__@'H!+@^%,?___X!Z`@`/A/C^
M__^0Z2'___^+A6S____H>/[__^NKZ,GX__]5B>575E.![(@```#HTRL``('#
MB(,``(G&B[OD____BP>)1?`QP(V%=/___XE$)`2)-"3H8?;__X7`=3:+E7S_
M__^!X@#P``"!^@!```!T"('Z`*```'4<QT0D!`(```")-"3H$?C__X7`#Y3`
M#[;`ZP(QP(M-\"L/=0N!Q(@```!;7E]=P^@^^/__58GE5U93@^3P@>P@!```
MZ$4K``"!P_J"``")1"08B50D%(N[Y/___XL'B80D'`0``#'`QT0D"/\#``"-
M="0<B70D!(V#AJC__XD$).AM]O__A<!^6HU0_X!\!!L`#X6%````A=)T2(E4
M)`B)5"00QT0D!"\```")-"3HC_?__X7`="R+5"00B50D#(ET)`B+1"08B40D
M!&6A`````"N#X/___XL`B00DZ*'W___K)HM$)!2)1"0(BT0D&(E$)`1EH0``
M```K@^#___^+`(D$).B9]?__BX0D'`0``"L'=0^-9?1;7E]=PXG"Z7C____H
M2O?__U6)Y5=64X/L+.A7*@``@<,,@@``B47HB=:+@^3___^)1=R+"(E-\#')
M@#H]=0.#Q@&)-"3HH??__XE%X(U5[(M%Z.C3^___B<>%P`^$U````(D$).B!
M]___.47@#X:M````BT7LC0R%`````(V#@`4``(E%Y(M%Z`^V$(32=0_I40$`
M`(/``0^V$(32=`6`^CUU\2M%Z(M]Y`,/B<^+3>"-1`@"B00DZ#[W__^)!X7`
M=$>+?>2+!XM5[(L,D(M%Z(U0`0^V`(@!A,!U$.M3@\(!#[9"_XA'`83`=$6)
MSXU)`3P]=>G&!STQP`^V%`:(5`<!@\`!A-)U\8M%W(MU\"LP#X7A````@\0L
M6UY?7<,QP`^V%`:(%`>#P`&$TG7RZ]B)S^O`C8.`!0``B47DBQ"+.H7_#X2B
M````,?^)^(/'`8L,NH7)=?2-!(4,````BXM@!0``A<EU5XE5V,>#8`4```$`
M``")!"3H?/;__X7`=(>-#+T`````B4PD"(E-U(M5V(E4)`2)1=B)!"3HV/+_
M_XM-Y(M%V(D!BTW4BT78QT2X!`````")?>SIQ?[__XE$)`2)%"3HGO+__XE%
MV(M-Y(D!A<`/A"W___^-#+T`````Z\@QP.FZ_O__N`@````Q_^EG____Z%WU
M__]5B>53@^3P@^P0Z&DH``"!PQZ```"-@\#F__^)1"0,BX/4____B40D"(V#
MF*C__XE$)`1EH0`````K@^#___^+`(D$).A$]/__BUW\B>Q=PU6)Y593@^3P
M@^P@Z!@H``"!P\U_``!EH0`````K@^#___^)QHL`B00DZ(+____'1"04````
M`(V#?ZC__XE$)!")1"0,C8.QD?__B40D"(V#M*C__XE$)`2+!HD$).A+]/__
MC67X6UY=PS'`PU6)Y5=64X'LN`0``.BK)P``@<-@?P``BT4(B85L^___BWT,
MBY/D____B95<^___BPJ)3?`QR8V5</O__XV#RZC__^@J^?__B<;'1"0$+P``
M`(N%;/O__XD$).BB\?__A<!T,8NU;/O__XGRC8/4J/__Z.'\__^)\(N-7/O_
M_XM5\"L1#X6(`0``@<2X!```6UY?7<.+A6S[__^)!"3HC_3__XF%9/O__XV#
MX:C__XF%:/O__XE$)`2)/"3H0?+__XG'A<!TG8V#R:C__XF%6/O__XV#NJG_
M_XF%8/O__X`_``^$VP```(7V=!2)?"0$B30DZ%KT__^%P`^$F@```(D\).@J
M]/__@'P'_R]U#H/H`<8$!P"`?`?_+W3RBXUD^___C40(`3W_`P``#X\R____
MBX5L^___B40D&(N%8/O__XE$)!2)?"00C8/=J?__B40D#,=$)`@`!```QT0D
M!`````"-O?#[__^)/"3H`/+__XV%=/O__XE$)`2)/"3H#O'__X7`=1*+A7S[
M__\E`/```#T`@```=$J+A6C[__^)1"0$QP0D`````.A2\?__B<>%P`^$JO[_
M_X`_``^%)?___X7V=`6`/BYT$(N]6/O__[@!````Z4'___^`?@$`=+CKZ,=$
M)`0!````B3PDZ%[R__^%P'6BB?J-@]2H___H4_O__XD\).B%\O__Z6?^___H
MB_+__U6)Y8M%"`^V$(G!A-)T$8/``8#Z+W4"B<$/MA"$TG7OB<A=PU6)Y593
M@^P0Z'4E``"!PRI]``"+=0B%]@^$HP```(`^``^$F@```(DT).C(\O__C40&
M_SG&<@SIF@```(/H`3G&="&`."^0=/,YQ@^#A0```(/H`3G&=`R`."]T)H/H
M`3G&=?2`/B]T6(V#NJG__XD$).C@\?__@\006UY=PX`X+W4'@^@!.<9R]"GP
MC5`"@?H`!```=T7'1"0,``0``(/``8E$)`B)="0$C;-@`0``B30DZ._O__^)
M\(/$$%M>7<.-@\FH__^)!"3HB/'__X/$$%M>7<,YQG6IZX@QP(/$$%M>7<-5
MB>575E.#[#3HBR0```5$?```B47$BXCD____B4W`BSF)??`Q_\=%SE]?14['
M1=)67U!!QT764E]#3,=%VD5!3E_'1=Y?("`@QT7B("`@(,=%YB`@("#'1>H@
M("`@9L=%[@``C5W(C;#CJ/__C;B`!0``B=J)\.C6]?__A<!T*HL'BU7(C020
MBU`$B1"%TG3B@\`$BU`$B1"%TG7TB=J)\.BL]?__A<!UUHM%Q(VP[*C__XVX
M@`4``(G:B?#HD/7__X7`="J+!XM5R(T$D(M0!(D0A=)TXH/`!(M0!(D0A=)U
M](G:B?#H9O7__X7`==:+1<2-L/2H__^-N(`%``")VHGPZ$KU__^%P'0JBP>+
M5<B-!)"+4`2)$(72=.*#P`2+4`2)$(72=?2)VHGPZ"#U__^%P'76BT7$C;#]
MJ/__C;B`!0``B=J)\.@$]?__A<!T*HL'BU7(C020BU`$B1"%TG3B@\`$BU`$
MB1"%TG7TB=J)\.C:]/__A<!UUHM%Q(VP!*G__XVX@`4``(G:B?#HOO3__X7`
M="J+!XM5R(T$D(M0!(D0A=)TXH/`!(M0!(D0A=)U](G:B?#HE/3__X7`==:+
M1<2-L!2I__^-N(`%``")VHGPZ'CT__^%P'0JBP>+5<B-!)"+4`2)$(72=.*#
MP`2+4`2)$(72=?2)VHGPZ$[T__^%P'76BT7$C;#+J/__C;B`!0``B=J)\.@R
M]/__A<!T*HL'BU7(C020BU`$B1"%TG3B@\`$BU`$B1"%TG7TB=J)\.@(]/__
MA<!UUHM%Q(VP(*G__XVX@`4``(G:B?#H[//__X7`="J+!XM5R(T$D(M0!(D0
MA=)TXH/`!(M0!(D0A=)U](G:B?#HPO/__X7`==:+1<2-L"JI__^-N(`%``")
MVHGPZ*;S__^%P'0JBP>+5<B-!)"+4`2)$(72=.*#P`2+4`2)$(72=?2)VHGP
MZ'SS__^%P'76BT7$C;`TJ?__C;B`!0``B=J)\.A@\___A<!T*HL'BU7(C020
MBU`$B1"%TG3B@\`$BU`$B1"%TG7TB=J)\.@V\___A<!UUHM%Q(VPU*C__XVX
M@`4``(G:B?#H&O/__X7`="J+!XM5R(T$D(M0!(D0A=)TXH/`!(M0!(D0A=)U
M](G:B?#H\/+__X7`==:)VHM]Q(V'/JG__^C<\O__B<*%P'0+C8<JJ?__Z+'V
M__^)VHM]Q(V'3ZG__^B[\O__B<*%P'0+C8=AJ?__Z)#V__^)VHM]Q(V';*G_
M_^B:\O__B<*%P'0QC8?+J/__Z&_V__^+1<2-D)BI__^-@`2I___H6_;__XM%
MP(M-\"L(=5B#Q#1;7E]=PXG:BWW$C8=\J?__Z%/R__^)PH7`=`V-AR"I___H
M*/;__^NW@7W?4$%27W6N@7WC0TQ%076E9H%]YTX]=9V-5>F+1<2-@""I___H
M^_7__^N*BUW$Z#OM__]5B>564X/L".A)(```@</^=P``B[/D____BP:)1?2+
M@RP!``"#^/]T#HM-]"L.=32#Q`A;7EW#C57PC8,@J?__Z,;Q__^%P'07#[8`
MA,!T$#PP#Y7`#[;`B8,L`0``Z\DQP.OTZ-+L__]5B>53@^P$Z.$?``"!PY9W
M``#H*^W__XD$).@#[?__A<!T`HL`@\0$6UW#58GE5U93@^PDZ+0?``"!PVEW
M``"+10B)1>B+N^3___^+!XE%\#'`C57LC8.:J?__Z$+Q__^%P'0'B<:`.`!U
M(HM%\"L'9I`/A98```"+5>B-@YJI__^#Q"1;7E]=Z?OT__^+1>B)1"0$B30D
MZ';I__^%P'0/BT7P*P=U9X/$)%M>7UW#BT7HB00DZ*CL__^)1>2)-"3HG>S_
M_XM5Y(U$`@*)!"3HGNS__XG"B70D$(V#X:C__XE$)`R+1>B)1"0(C8/=J?__
MB40D!(D4)(E5Z.@R[/__BT7P*P>+5>@/A&W____HO^O__U6)Y5=64X'L+($`
M`.C)'@``@<-^=@``BT4(B87P?O__BX/D____B87H?O__BPB)3?`QR8V#MJG_
M_XF%!'___XV#R:C__XF%"'___\>%#'___P````"-@UJI__^)A2!___^-@[RI
M__^)A21___^-@W>I__^)A2A___^-@\2I__^)A2Q____'A3!___\`````C8.J
MJ?__B87\?O__B840?___C8/(J?__B844?___QX48?___`````(V]`'___XGZ
MC8/+J/__Z,7O__^%P'0+B<:`.``/A08%``#H#_[__XG"A<`/A)0$``")%"2)
ME?Q^___H6>O__XU$``&)!"3H7>O__XF%^'[__XN5_'[__P^V`H3`=$B+M?A^
M__^-B]&I__^)C?Q^__^)O?1^__^)]XG6#[;`B40D"(N%_'[__XE$)`2)/"3H
MU>K__X/&`8/'`@^V!H3`==J+O?1^__^-M1Q___^-@V&I__^)O?Q^__^)]^L)
M@\<$BP>%P'0UBY7\?O__Z`CO__^)QH7`=.:`.`!TX>A?\?__A<!TV(N]_'[_
M_XDT).@&ZO__B<*%P'56ZP:+O?Q^__^+E01___^-M01___^)O?Q^__^)U^L*
MBWX$A?]T*8/&!(`_`'0AB?CH$_'__X7`=.:)/"3HP.G__X7`=-J)PHN]_'[_
M_^L(B[W\?O__,=*)%"2)E?Q^___H/.K__XG&BX7X?O__B00DZ"SJ__^-M`8$
M!```B30DZ"WJ__^)P8N%^'[__XE$)!2-@]:I__^)1"00C8.ZJ?__B87T?O__
MB40D#(N5_'[__XE4)`B-@]NI__^)1"0$B8WX?O__B0PDZ*7I___'1"0$P`$`
M`(N-^'[__XD,).BOZ/__@_C_#X2!`@``C84T?___B40D!(N%^'[__XD$).C>
MYO__B87D?O__A<!T7XN%^'[__XE$)`R+A?!^__^+`(E$)`B-@X2J__^)1"0$
MBX/\____!;````")!"3HX>;__\>%['[__P````"+A>A^__^+3?`K"`^%,@4`
M`(N%['[__X'$+($``%M>7UW#BX4\?___)0#P```]`$```'6/BX5,?___B87\
M?O__Z/+H__\YA?Q^__\/A7+___^+A3Q___\E_P$``#W``0``#X5<____B30D
MZ/CH__^)A>Q^__^)^HV#I:G__^@5[?__A<`/A'@"``")!"3H)>C__XE$)`2+
MA?!^__^+`(D$).B`\___B87\?O__A<`/A$X"``"+O?Q^__^)/"3HE>C__X/X
M`W8UC70'_+D%````C;ODJ?__\Z8/E\*`V@"$TG4:@_@$#X2&`P``B[W\?O__
M@'P'^R\/A'4#``#HB_K__X7`=2#'1"0$`````(N%_'[__XD$).CLY___B<>%
MP`^%\`$``(V3F*G__XV#(*G__^A'\/__Z$SG__^-LW^H__^)="04B40D$(N%
M]'[__XE$)`R+A?A^__^)1"0(C8/]J?__B40D!(N%['[__XD$).BRY___C;L+
MJO__B;7\?O__B[7D?O__B;WP?O__B[WL?O__ZTKHC>;__X,X$755@\8!Z.#F
M__^+C?Q^__^)3"08B70D%(E$)!"+A?1^__^)1"0,BX7X?O__B40D"(N%\'[_
M_XE$)`2)/"3H2.?__\=$)`3``0``B3PDZ%CF__^#^/]TH8N%^'[__XD$).A5
MY/__B[WL?O__B?J-@\NH___H:.___XD\).@#^O__Z=[]__^-="8`D.C[Y?__
M@S@1#X1L_?__9I#HZ^7__XL`B40D$(N%^'[__XE$)`R+A?!^__^+`(E$)`B-
M@TBJ__^)1"0$BX/\____!;````")!"3H8N3__\>%['[__P````#I?/W__XVU
M$'___XN%_'[__^L*BT8$A<!T+(/&!(GZZ/3J__^%P'3K@#@`=.:)!"3H`^;_
M_XG"A<`/A3+[__^+1@2%P'74QP0D#0```.B6YO__B87X?O__C9.OJ?__N%,`
M``#I-OO__XD$).@Q^?__B30DZ,#E__^)A>Q^___I_OS__XN%\'[__XL`B87\
M?O__Z9_]___'1"0,`@```,=$)`3N____QT0D"/____^)!"3HPN7__\=$)`@&
M````C;7P?___B70D!(D\).A8Y/__@+WP?___`'4-@+WQ?___0P^$8P$``,=$
M)`P`````QT0D!`````#'1"0(`````(D\).ARY?__Z,$1``")A?Q^___K%HE$
M)`B)="0$BX7\?O__B00DZ/X1``#'1"0(`(```(ET)`2)/"3HZ^/__X7`?]*)
M/"3H3^+__XN%_'[__XE$)`2-M;-___^)-"3HUQ,``(V]QW___XF]Y'[__XV#
MT:G__XF%_'[__XF]\'[__P^V!HE$)`B+A?Q^__^)1"0$B3PDZ!#E__^#Q@&#
MQP([M?!^__]UV<:%[W___P"-@W^H__^)1"04BX7D?O__B40D$(N%]'[__XE$
M)`R+A?A^__^)1"0(C8/NJ?__B40D!(N%['[__XD$).B[Y/__Z8/]__^+A?!^
M__^+4`2%T@^$>OS__XD4)(F5\'[__^C'Y/__@_@##X9C_/__BY7P?O__C70"
M_+D%````C;OIJ?__\Z8/E\`<`(3`#X4__/__B97\?O__Z33\__^`O?)___]!
M#X60_O__@+WS?___0P^%@_[__X"]]'___T@/A7;^__^`O?5___]%#X5I_O__
MQT0D#`(```#'1"0$QO___\=$)`C_____B3PDZ-OC___'1"0(*0```(ET)`2)
M/"3H=^+__XV#?ZC__XE$)!2)="00Z?W^___H?^/__U6)Y5=64X/D\(/L(.B)
M%@``@<,^;@``BX/D____B40D%(LXB7PD'#'_9:$`````*X/@____BP`/ME!D
MB%!EC7PD&(GZC8,$J?__Z`#H__^%P'0)@#@Q#X26`0``C78`Z)GQ___'1"0,
M`P```,=$)`@!````C8,<JO__B40D!&6A`````"N#X/___XG&BP")!"3HJ>'_
M_X7`=#2-DQZJ__^)5"0(BU`,B40D$(L2B50D!(L6B10DZ/3@__^+1"00BT`,
MBP#V0`I`#X5*`0``QT0D#`,```#'1"0(`0```(V#(ZK__XE$)`1EH0`````K
M@^#___^)QHL`B00DZ#_A__^%P(E$)!!T,(GZC8/4J/__Z#KG__^%P(M,)!`/
MA.````")1"0(BT$,BP")1"0$BP:)!"3H=^#__\=$)`@!````C8,EJO__B40D
M!&6A`````"N#X/___XG&BP")!"3H'>'__XV3.JK__XE4)`B)1"0$BP:)!"3H
M->#__XL&QD!E`(GZC8/+J/__Z,+F__^)@V0%``"%P'0UQT0D!,`!``")!"3H
M6.'__X/X$70(C5`!@_H!=W>+1"04BWPD'"LX#X6/````C67T6UY?7<.+@V@%
M``")!"3HYO7__XF#9`4``(7`=;.-@]BJ__^)!"3HK>#__X!X`0`/A&C^___I
M6_[__XM!#(N3:`4``(L2BP#H+NG__^D@____B40D!(L&B00DZ,G@___IH_[_
M_XE$)`R+@V0%``")1"0(BX-H!0``BP")1"0$C8/\JO__B00DZ$S@___H)^'_
M_U6)Y5=64X/L".@T%```@</I:P``BU4(B10DB57PZ)[N__^)!"3H<N[__XG&
MZ+OS__^%P'0BBU7PA=)T&X`Z`'06N00```"-N]:I___SI@^7P!P`A,!T"(/$
M"%M>7UW#B="#Q`A;7E]=Z6+F__]FD&:09I!FD&:058GE5U93@>QP`0``Z+X3
M``"!QV]K``")O83^__^)PXF%G/[__XN_Y/___XF]B/[__XL'B47P,<"-E;#^
M__^+3(,<#\F)#(*#P`&#^!!U[XU-L(M"-#-"(#-""#,"T<")0D"#P@0YRG7I
MB[6<_O__BQZ+3@2+?@B+1@R)A:S^__^+5A"+A;#^__^)E8S^__^-E`*9>8):
MB=C!P`4!T(GZB[6L_O__,?(ARC'R`<*)C9#^__^)R,'(`HG&B?@Q\"'8B;VD
M_O__,?B+C;3^__^+O:S^__^-C`^9>8):`<B)T<'!!0'(B9V4_O__B=G!R0*)
M\XF-H/[__S'+B=DAT3'QB[VX_O__BYVD_O__C;P[F7F"6@'YB<?!QP4!SXF]
MJ/[__\'*`HN]H/[__XG[,=.)V2'!,?F+G;S^__^-M!Z9>8):`?&+G:C^___!
MPP4!R\'(`HG1,<$CC:C^__\QT8NUP/[__XVT-YEY@EH!\8G>P<8%`<Z+O:C^
M___!SP*)P3'YB9V@_O__(=DQP8N=Q/[__XV4&IEY@EH!T8GRP<(%`<J)E:C^
M__^+E:#^___!R@*)^S'3B=DA\3'YBYW(_O__C9P8F7F"6@'9BX6H_O__P<`%
MB<,!R\'.`HG0,?`CA:C^__\QT(N-S/[__XV,#YEY@EH!R(G?P<<%`<>)O:#^
M__^+A:C^___!R`*)\3'!(=DQ\8N]T/[__XV\.IEY@EH!^8N]H/[__\''!0'/
MP<L"B<(QVB.5H/[__S'"BXW4_O__C8P.F7F"6@'*B?G!P04!RHF5J/[__XN5
MH/[__\'*`HG9,=$A^3'9B[78_O__C;0PF7F"6@'QBX6H_O__P<`%B<8!SL'/
M`HG0,?@CA:C^__\QT(N-W/[__XV,"YEY@EH!R(GSP<,%`=B)A:#^__^+A:C^
M___!R`*)^S'#B=DA\3'YBYW@_O__C9P:F7F"6@'9BY6@_O__P<(%B=,!R\'.
M`HG",?(CE:#^__\QPHN-Y/[__XV,#YEY@EH!RHG?P<<%`=>)O:C^__^+E:#^
M___!R@*)\3'1(=DQ\8N]Z/[__XV\.)EY@EH!^8N%J/[__\'`!8G'`<_!RP*)
MT#'8(X6H_O__,="+C>S^__^-C`Z9>8):`<B)^<'!!0'(B86@_O__BX6H_O__
MP<@"B=DQP2'Y,=F+M?#^__^-M#*9>8):`?&+E:#^___!P@6)U@'.P<\"B<*)
MO9C^__\Q^HN]H/[__R'Z,<*+C?3^__^-C`N9>8):`<J)\\'#!0'3B9VH_O__
MB?K!R@*+O9C^__^)^3'1(?&)^S'YB[WX_O__C80XF7F"6@'(BXVH_O__P<$%
M`<C!S@*)T3'Q(XVH_O__,=&+O?S^__^-O#N9>8):`?F)Q\''!0'YBYVH_O__
MP<L"B[T`____C;PZH>O9;HGR,=HQP@'ZB<_!QP4!^L'(`HN]!/___XV\/J'K
MV6Z)WC'&,<X!_HG7P<<%`?Z)S\'/`HN-"/___XV<"Z'KV6Z)P3'Y,=$!V8GS
MP<,%`=F)T\'+`HN5#/___XV4$*'KV6Z)^#'8,?`!T(G*P<(%`=#!S@*+E1#_
M__^-O!>AZ]ENB=HQ\C'*`?J)Q\''!0'ZP<D"B[T4____C;P[H>O9;HGS,<LQ
MPP'[B=?!QP4!^\'(`HG'BX48____C;0&H>O9;HG(,?@QT`'PB=[!Q@4!\,'*
M`HG6BY4<____C901H>O9;HGY,?$QV0'1B<+!P@4!T<'+`HN5(/___XV\%Z'K
MV6Z)\C':,<(!^HG/P<<%`?K!R`*)QXN%)/___XV$!J'KV6Z)WC'^,<X!QHG0
MP<`%`<;!R0*+A2C___^-G`.AZ]ENB?@QR#'0`=B)\\'#!0'8B=/!RP*+E2S_
M__^-E!>AZ]ENB<\QWS'W`=>)PL'"!0'7P<X"BY4P____C8P1H>O9;HG:,?(Q
MP@'*B?G!P04!RL'(`HG!BX4T____C80#H>O9;HGS,<LQ^P'#B=#!P`4!P\'/
M`HN%./___XVT!J'KV6Z)R#'X,=`!\(G>P<8%`?#!R@*)UHN5//___XV4$:'K
MV6Z)^3'Q,=D!T8G"P<(%`='!RP*+E4#___^-O!>AZ]ENB?(QVC'"`?J)S\''
M!0'ZP<@"B<>+A43___^-A`:AZ]ENB=XQ_C'.`<:)T,'`!0'&P<D"BX5(____
MC9P#H>O9;HGX,<@QT`'8B?/!PP4!V,'*`HN=3/___XV\'Z'KV6Z)RS'3,?,!
M^XG'P<<%`=^)O:#^___!S@*)TPGS(<.)WXG3(?,)^XN]4/___XV\.=R\&X\!
M^XN]H/[__\''!0'?B;VH_O__P<@"B<>)\PG#BX6@_O__(<.)\2'Y"=F+G53_
M__^-E!K<O!N/`=&+G:C^___!PP4!RXG"P<H"B?D)T2.-J/[__XF]H/[__R'7
M"?F+A5C___^-M`;<O!N/`?&)W\''!8G^`<Z+A:C^___!R`*)A:C^__^)T0G!
M(=F+A:C^__\AT`G!BX5<____B[V@_O__C80'W+P;CP'!B?#!P`4!R(G'B=C!
MR`*+G:C^__\)PR'SBXVH_O__(<$)V8N=8/___XV<&MR\&X\!V8GZP<(%B=,!
MR\'.`HG""?*)T8F]H/[__R'YB<(A\@G*BXUD____B[VH_O__C8P/W+P;CP'*
MB=_!QP4!UXF]J/[__XN5H/[__\'*`HGQ"=&)SR'?B?$AT0GYB[UH____C;PX
MW+P;CP'YBX6H_O__P<`%B<<!S\'+`HG0"=B+C:C^__\AP8G0(=@)R(N-;/__
M_XV,#MR\&X\!R(GYP<$%`<B)A:#^__^+A:C^___!R`*)V0G!(?F)SHG9(<$)
M\8NU</___XVT,MR\&X\!\8N5H/[__\'"!8G6`<[!SP*)P@GZBXV@_O__(=&)
MPB'Z"<J+C73___^-C`O<O!N/`<J)\\'#!0':B96H_O__BY6@_O__P<H"B?L)
MTR'SB?DAT0G9BYUX____C9P8W+P;CP'9BX6H_O__P<`%B<,!R\'.`HG0"?"+
MC:C^__\AP8G0(?`)R(N-?/___XV,#]R\&X\!R(G?P<<%`<>)O:#^__^+A:C^
M___!R`*)\0G!B<\AWXGQ(<$)^8M]@(V\.MR\&X\!^8N]H/[__\''!0'/P<L"
MB<()VHN-H/[__R'1B<(AV@G*BTV$C8P.W+P;CP'*B?G!P04!RHF5J/[__XN5
MH/[__\'*`HG9"=$A^8G.B=DAT0GQBW6(C;0PW+P;CP'QBX6H_O__P<`%B<8!
MSL'/`HG0"?B+C:C^__\AP8G0(?@)R(M-C(V,"]R\&X\!R(GSP<,%`=B)A9C^
M__^+A:C^___!R`*)^PG#(?.)^8F%H/[__R'!"=F+79"-G!K<O!N/`=F+A9C^
M__^)PL'"!8G3`<N)G:C^___!S@*+G:#^__^)V@GRB=$AP8G:(?()RHM-E(V,
M#]R\&X\!RHN]J/[__\''!0'7B<+!R@*)\0G1(XVH_O__B?`AT`G!BT68C80#
MW+P;CP'(B?G!P04!R(F%H/[__XN=J/[__\'+`HG1"=DA^8G0(=@)P8M%G(VT
M!MR\&X\!\8N%H/[__\'`!0'!P<\"B?Z+?:"-E#K6P6+*B=\Q]S.]H/[__P'7
MB<C!P`4!QXN%H/[__\'(`HM5I(V<$];!8LJ)\C'",<H!VHG[P<,%`=K!R0*+
M7:B-M![6P6+*B<,QRS'[`?.)UL'&!0'SP<\"BW6LC;0PUL%BRHG(,?@QT`'P
MB=[!Q@4!\,'*`HG6BU6PC901UL%BRHGY,?$QV0'1B<+!P@4!T<'+`HM5M(V\
M%];!8LJ)\C':,<(!^HG/P<<%`?K!R`*)QXM%N(V$!M;!8LJ)WC'^,<X!QHG0
MP<`%`<;!R0*+1;R-G`/6P6+*B?@QR#'0`=B)\\'#!0'8B=/!RP*+5<"-E!?6
MP6+*B<\QWS'W`=>)PL'"!0'7P<X"BU7$C8P1UL%BRHG:,?(QP@'*B?G!P04!
MRL'(`HG!BT7(C80#UL%BRHGS,<LQ^P'#B=#!P`4!P\'/`HM%S(VT!M;!8LJ)
MR#'X,=`!\(G>P<8%`?#!R@*)UHM5T(V4$=;!8LJ)^3'Q,=D!T8G"P<(%`='!
MRP*+5=2-O!?6P6+*B?(QVC'"`?J)S\''!0'ZP<@"B<>+1=B-A`;6P6+*B=XQ
M_C'.`<:)T,'`!0'&P<D"BT7<C9P#UL%BRHGX,<@QT`'8B?/!PP4!V(G3P<L"
MBU7@C907UL%BRHG/,=\Q]P'7B<+!P@4!U\'.`HM5Y(V,$=;!8LJ)VC'R,<(!
MRHGYP<$%`<K!R`*+3>B-G`O6P6+*B?$QP3'Y`=F)T\'#!0'9B8VH_O__P<\"
MBUWLBXV4_O__C9P9UL%BR@'>B<,Q^S'3`?.+C:C^___!P04!RXNUG/[__XD>
MBXVH_O__`XV0_O__B4X$P<H"`Y6D_O__B58(`[VL_O__B7X,`X6,_O__B480
MBX6(_O__BW7P*S!U"X'$<`$``%M>7UW#BYV$_O__Z'S3__]5B>53@^P$Z(L&
M``"!PT!>``#'!"1@````Z/[3___'``$C16?'0`2)J\WOQT`(_MRZF,=`#'94
M,A#'0!#PX=+#QT`4`````,=`&`````#'0%P`````@\0$6UW#58GE5U93@^P,
MBUT,BT40P>`#BU4(,<D#0A0/DL&+4AB#^0&#VO^+30B)012+11#!Z!T!T(E!
M&(G(BTE<C5`<A<ET6+Y`````*<Z+11`Y\`^/.P$``(E%\(T\"HG>@_@$#X,]
M`0``]D7P`G0"9J7V1?`!=`&DBWT(BT]<`<&)3UR#^4`/A=H```")5?`I11`!
MPXGXZ-GQ__^+5?"#?1`_#XX;`0``BT40@^A`B47LB<?![P:-=P'!Y@8!WHEU
M\(E]Z(G7B=Z+70B+!HD'BT8$B4<$BT8(B4<(BT8,B4<,BT80B4<0BT84B4<4
MBT88B4<8BT8<B4<<BT8@B4<@BT8DB4<DBT8HB4<HBT8LB4<LBT8PB4<PBT8T
MB4<TBT8XB4<XBT8\B4<\@\9`B=CH0?'__SMU\'63BW7PB?J+?>C!YP:+1>PI
M^(E%$(M%$(G7@_@$<R2H`G48J`%U$8M%"(M=$(E87(/$#%M>7UW#I.OL9J6H
M`73FZ_7VP@%U6O?'`@```'5!B<'!Z0+SI:@"=,CKWHGPB47PC3P*B=Z#^`0/
M@L/^___WQP$```!U4_?'`@```'4YBTWPP>D"\Z7IIO[__XG>ZX0/MQ9FB1>#
MQP*#Q@*#Z`+KK@^V!HM="(A#'(/'`8/&`8M%$(/H`>N/#[<.9HD/@\<"@\8"
M@VWP`NNU#[8+B`^#QP&-<P&-2/^)3?#KFE6)Y5=64X/L%.@9!```!=);``")
M1?"+=0B+70R+4Q2)T`_(B47HBT,8#\B)1>S!Z@.#XC^->QR-0@'&!!>`C4P7
M`8/X.`^.^0```+I`````*<)T#3'`Q@0!`(/``3G0<O6)V.CX[___NC@````Q
MP/?'`0````^%.@$``/?'`@````^%)`$``(G1P>D"\ZOVP@(/A00!``"#X@%T
M`:J+1>R)0U2+1>B)0UB)V.BP[___BP/!Z!B(!HL#P>@0B$8!BP.(9@*+`XA&
M`P^V0P>(1@0/MT,&B$8%BT,$B&8&BT,$B$8'#[9#"XA&"`^W0PJ(1@F+0PB(
M9@J+0PB(1@L/MD,/B$8,#[=##HA&#8M##(AF#HM##(A&#P^V0Q.(1A`/MT,2
MB$81BT,0B&82BT,0B$83B1PDBUWPZ&3-__^#Q!1;7E]=P[HX````*<*)SS')
M@_H$<QGVP@)T!(G(9JN#X@$/A#?___^)R.DO____]\<!````=53WQP(```!U
M0X/Z!'+2B="#X/R)1>0QP(D,!X/`!#M%Y'+U`<?KN6:K@^(!#X3W_O__Z?'^
M__]FJX/J`NG2_O__JKHW````Z;O^__^)R&:K@^H"Z[2)R*J#Z@'KI&:09I!F
MD&:09I!FD&:0D(M=\.C8S/__BUWPZ-#,__]5B>575E.#Y/"#[$#H*@(``('#
MWUD``(M%#(E$)#2+11")1"0PBX/D____B40D*(LXB7PD/#'_C40D,(E$)`B-
M1"0TB40D!(U%"(D$).B^S?__BX/H____B40D"(E$)`2+@_3___^)!"3H\LW_
M_XN#V/___X`X``^$(`$``&6A`````"N#X/___XL`@(A2`@```XM%"(UX`XE\
M)"R#P`0]____/P^';0$``,'@`HD$).@;S?__B<&)@V@%``"+="0TBP:)`8V#
M0*K__XE!!(V#,`$``(L`B4$(C8-#JO__B4$,BWT(@_\!#XXN`0``C48$C5$0
MC32^B4PD)(L(B0J#P`2#P@0YQG7RBTPD)(/'`\<$N0````#'1"00`````(E,
M)`R+1"0LB40D"(V#(X#__XE$)`2+@VP%``")!"3H;<W__XG&A<`/A($```"+
M@VP%``")!"3HY<O__XU\)#B)^HV#%*G__^B$TO__A<!T<XN#;`4``(D$).B"
MR___Z.W,__^+1"0HBWPD/"LX#X6?````B?"-9?1;7E]=P^C.R___B8-L!0``
MA<!T>HD$).@,R___9:$`````*X/@____BP#&@-,%````Z:_^__^+@VP%``")
M!"3H9,W__XG&Z6K___^+@V0%``"%P'0-B00DZ`3L___I=O___XGZC8/+J/__
MZ.G1__^)@V0%``"%P`^$6____^O6Z.3,__^_!````.GJ_O__QP0D`0```.CN
MR?__Z.G,__^+!"3#BQPDPXL\),,`````````````````58GEZ+C0___)PP``
M<'-?<W1R:6YG<R!M:7-S:6YG"@`E<R\E<P`O<')O8R]C=7)P<F]C+V5X90!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0`+@!005)?5$5-4`!005)?4%)/1TY!344`.@!015),-4Q)0@!015),3$E"
M`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)5
M1P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!
M5$@`55-%4@!365-414T`+W1M<"\`5$5-4$1)4@!435``55-%4DY!344`)3`R
M>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-3(`+64`+2T````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N
M<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H
M*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA
M;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII
M9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@
M96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD
M;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]
M("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@
M,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L
M("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I
M(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P
M;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@
M=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@
M(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L
M;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X
M="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@
M,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F
M=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#
M(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF
M(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M
M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O
M+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L
M("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F
M:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@
M("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?
M1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@
M("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P
M87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6
M>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%2
M1U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS
M:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B
M)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*
M)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T
M(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T[
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E96YV(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D
M<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@
M)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D
M97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E
M<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD
M;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM
M>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N
M92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@
M0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE
M<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B
M:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT
M(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F
M:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C
M(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D
M;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y
M(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@
M)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D
M,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL
M(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N
M=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U
M9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D
M(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE
M(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT
M*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT
M9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C
M;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N
M86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE
M7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]
M(")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H
M+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@
M)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P
M97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D
M:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET[
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q
M6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R
M7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R
M<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO
M72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X=')A8W14
M;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"![
M"FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@[
M"D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE
M<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@
M:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E
M<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?
M<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*
M<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H
M($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P
M871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*
M;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92![
M"B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!
M4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=
M*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@
M,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@
M-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I[
M"G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F
M:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B
M)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D
M9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*
M<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N
M86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE
M('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P
M<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H
M)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@
M)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R
M;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[
M4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D
M:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E
M;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U
M8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O
M;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.
M($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?
M)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE
M86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V
M86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB
M*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#
M3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I+F,````!&P,[&`$`
M`"(```!4B___8`(``#2/__^$`@``9(___S0!``"0C___7`$``*F0___$`0``
M[I#__P0"```TD___F`(```R4___D`@``FY7__Q0#```FEO__1`,``!J7__]T
M`P``!YG__Z0#``!7F?__S`,``,"9___T`P``PYG__P@$``#9F___.`0``/V;
M__]8!```XIS__Z@$```IH?__V`0``)*A__\$!0``O:'__R@%``"EHO__:`4`
M`.6J__^8!0``/:W__\@%``"TK?__-`8``.BZ__]D!@``0[O__X@&``!4O?__
MN`8``#2___^P`0``/+____`!``!$O___!`8``'O!__\D`@``?\'__S@"``"#
MP?__3`(``!0``````````7I2``%\"`$;#`0$B`$``"0````<````*([__RP`
M````00X(A0)"#05"A@.#!&3#0<9!Q0P$!``L````1````"R.__\9`0```$$.
M"(4"0@T%1H<#A@2#!0)0"L-!QD''0<4,!`1!"P`@``````````%Z4@`!?`@!
M&PP$!(@!#`4(@P6%`H8$AP,````0````*````'R]__\(`````````"@```"L
M````W8[__T4`````00X(A0)"#05&AP.&!(,%>,-!QD''0<4,!`0`$````&@`
M``!$O?__"``````````<````[````.*.__]B`0```$$."(4"0@T%1H<#A@2#
M!1`````,`0``3[___P0`````````$````"`!```_O___!``````````0````
M-`$``"^___\$`````````"````!(`0``[(C__^`#````#@A&#@Q*#PMT!'@`
M/QH[*C(D(A````!L`0``J(S__R``````````2````(`!``"4D/__V`````!!
M#@B%`D(-!4:'`X8$@P4"D@K#0<9!QT'%#`0$00M@"L-!QD''0<4,!`1!"T@*
MPT'&0<=!Q0P$!$$+`"P```#,`0``()'__X\!````00X(A0)"#05)AP.&!(,%
M=0K#0<9!QT'%#`0$00L``"P```#\`0``?Y+__XL`````00X(A0)"#05)AP.&
M!(,%`G8*PT'&0<=!Q0P$!$$+`"P````L`@``VI+___0`````00X(A0)"#05,
MAP.&!(,%`M4*PT'&0<=!Q0P$!$$+`"P```!<`@``GI/__^T!````00X(A0)"
M#05&AP.&!(,%`P(!"L-!QD''0<4,!`1!"R0```",`@``6Y7__U``````00X(
MA0)"#05'@P,"1,,-!$'%#@0````D````M`(``(.5__]I`````$$."(4"0@T%
M2(8#@P0"6\-!QD'%#`0$$````-P"``#$E?__`P`````````L````\`(``+.5
M__\6`@```$$."(4"0@T%28<#A@2#!0*$"L-!QD''0<4,!`1!"P`<````(`,`
M`)F7__\D`````$$."(4"0@T%8,4,!`0``$P```!``P``G9?__^4`````00X(
MA0)"#05%A@.#!`)S"L-!QD'%#`0$00L"0`K#0<9!Q0P$!$$+4@K#0<9!Q0P$
M!$$+3,-!QD'%#`0$````+````)`#```RF/__1P0```!!#@B%`D(-!4:'`X8$
M@P4#X@,*PT'&0<=!Q0P$!$$+*````,`#``!)G/__:0````!!#@B%`D(-!46&
M`X,$;`K#0<9!Q0P$!$$+```@````[`,``(:<__\K`````$$."(4"0@T%1(,#
M8L-!Q0P$!``\````$`0``(V<___H`````$$."(4"0@T%1H<#A@2#!0)1"L-!
MQD''0<4,!`1%"UX*PT'&0<=!Q0P$!$$+````+````%`$```UG?__0`@```!!
M#@B%`D(-!4F'`X8$@P4#"@,*PT'&0<=!Q0P$!$$++````(`$``!%I?__6`(`
M``!!#@B%`D(-!4F'`X8$@P4#O`$*PT'&0<=!Q0P$!$$+.````+`$``!MI___
M;0````!!#@B%`D(-!4:'`X8$@P4"4@K#0<9!QT'%#`0$00M&PT'&0<=!Q0P$
M!```+````.P$```XN?__-P(```!!#@B%`D(-!4F'`X8$@P4#C0$*PT'&0<=!
MQ0P$!$$++````!P%``!XI___-`T```!!#@B%`D(-!4F'`X8$@P4#&0T*PT'&
M0<=!Q0P$!$$+(````$P%``!\M/__6P````!!#@B%`D(-!42#`P)2PT'%#`0$
M+````'`%``"SM/__$0(```!!#@B%`D(-!4:'`X8$@P4#7@$*PT'&0<=!Q0P$
M!$$++````*`%``"4MO__T0$```!!#@B%`D(-!4:'`X8$@P4#-P$*PT'&0<=!
MQ0P$!$$+````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#_____`````/____\`
M``````````$````!`````0```*8"```!````W@(```$```#[`@```0```!H#
M```/````B@0```P````0$@``#0```&!(```$````>`$```4```#4"@``!@``
M`)0$```*````SP0```L````0````%0`````````#`````*````(```#H`0``
M%````!$````7````'!```!$```"D#P``$@```'@````3````"````/O__V\`
M```(^O__;P0`````````````````````````````````````````````````
M``````````````````````````````````````````````````#PG@``````
M````````````\)X`````````````-A(``$82``!6$@``9A(``'82``"&$@``
MEA(``*82``"V$@``QA(``-82``#F$@``]A(```83```6$P``)A,``#83``!&
M$P``5A,``&83``!V$P``AA,``)83``"F$P``MA,``,83``#6$P``YA,``/83
M```&%```%A0``"84```V%```1A0``%84``!F%```=A0``(84``"6%```IA0`
M`+84``#&%```UA0``.84``#V%```!A4``!85```F%0``-A4``$85``!6%0``
M9A4``'85``"&%0``EA4``*85``"V%0``QA4``-85``#F%0``]A4``$2A```$
MH0``````````````````````````````````````````````````_____T!+
M``!'0T,Z("A.971"4T0@;F(Q(#(P,C(P-S(R*2`Q,"XT+C``1T-#.B`H;F(Q
M(#(P,C(P-S(R*2`Q,"XT+C``)$YE=$)31#H@8W)T,"Y3+'8@,2XT(#(P,3@O
M,3$O,C8@,3<Z,S<Z-#4@:F]E<F<@17AP("0`)$YE=$)31#H@8W)T,"UC;VUM
M;VXN8RQV(#$N,C<@,C`R,B\P-B\R,2`P-CHU,CHQ-R!S:W)L;"!%>'`@)``D
M3F5T0E-$.B!C<G1I+E,L=B`Q+C$@,C`Q,"\P."\P-R`Q.#HP,3HS,R!J;V5R
M9R!%>'`@)``D3F5T0E-$.B!C<G1B96=I;BY3+'8@,2XQ(#(P,3`O,#@O,#<@
M,3@Z,#$Z,S,@:F]E<F<@17AP("0`)$YE=$)31#H@8W)T96YD+E,L=B`Q+C$@
M,C`Q,"\P."\P-R`Q.#HP,3HS,R!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G1N
M+E,L=B`Q+C$@,C`Q,"\P."\P-R`Q.#HP,3HS-"!J;V5R9R!%>'`@)```\<\"
M``````````````````@````(````"`````@````;`````0``````````*BHJ
M($YO($QA8F5L(%!R;W9I9&5D("HJ*@``\<\"``````````````````@````(
M````"`````@````;`````0``````````*BHJ($YO($QA8F5L(%!R;W9I9&5D
M("HJ*@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N;F5T8G-D+FED96YT`"YN
M;W1E+FYE=&)S9"YP87@`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN
M`"YR96PN<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD
M>6YA;6EC`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`+E-53E=?8W1F
M```````````````````````````````````````````````````````+````
M`0````(````T`0``-`$``!<```````````````$`````````$P````<````"
M````3`$``$P!```8```````````````$`````````"8````'`````@```&0!
M``!D`0``%```````````````!``````````W````!0````(```!X`0``>`$`
M`!P#```%``````````0````$````/0````L````"````E`0``)0$``!`!@``
M!@````$````$````$````$4````#`````@```-0*``#4"@``SP0`````````
M`````0````````!-````"0````(```"D#P``I`\``'@````%``````````0`
M```(````5@````D```!"````'!```!P0``#H`0``!0```!8````$````"```
M`%\````!````!@```!`2```0$@``"@``````````````$`````````!:````
M`0````8````@$@``(!(``.`#`````````````!`````$````90````$````&
M`````!8````6```@```````````````(````"````&X````!````!@```"`6
M```@%@``,S(`````````````$`````````!T`````0````8```!@2```8$@`
M``H``````````````!``````````>@````$````"````;$@``&Q(``!>/@``
M```````````$`````````((````!`````@```,R&``#,A@``'`$`````````
M````!`````````"0`````0````(```#HAP``Z(<``-`%``````````````0`
M````````F@````$````#````W)X``-R.```(```````````````$````````
M`*$````!`````P```.2>``#DC@``"```````````````!`````````"H````
M`0````,```#LG@``[(X```0```````````````0`````````K0````8````#
M````\)X``/".``#@````!@`````````$````"````&D````!`````P```-"?
M``#0CP``,```````````````!`````0```"V`````0````,`````H````)``
M```!``````````````0````$````OP````$````#`````*$```"1```T````
M```````````$`````````,4````(`````P```$"A```TD0``1`0`````````
M````0`````````#*`````0```#``````````-)$``#T```````````````$`
M```!````'P````$````P`````````'&1``!2`0`````````````!`````0``
M`-,````!``````````````#$D@``CP``````````````!``````````!````
D`P``````````````4Y,``-T```````````````$`````````
